@@ -40,6 +40,8 @@ extern int yylex() ;
 
 extern int tabSpaces; // FIXME
 
+static char *get_input_file_name(char *file_name);
+
 void
 processFile( char *progname, char *version,
              char *inputFileName, char *outputFileName, char *docTitle, 
@@ -57,14 +59,20 @@ processFile( char *progname, char *version,
     }
   }
 
-  if ( inputFileName ) {
-      in = freopen (inputFileName, "r", stdin);
-      if (!in) {
-        cerr << "Error in opening " << inputFileName
-             << " for input" << endl ;
-        exit(1) ;
-      }
-  }
+  if (inputFileName)
+    {
+      char *input_file_name = get_input_file_name (inputFileName);
+
+      in = freopen (input_file_name, "r", stdin);
+      if (!in) 
+        {
+          cerr << "Error in opening " << inputFileName
+               << " for input" << endl ;
+          exit(1) ;
+        }
+
+      delete input_file_name;
+    }
 
   /*
    * Use default values for any options not provided
@@ -102,6 +110,21 @@ processFile( char *progname, char *version,
     delete sout ;
 }
 
+char *
+get_input_file_name(char *file_name)
+{
+  unsigned int length = strlen (CHROOT_INPUT_DIR);
+
+  if (length != 0)
+    {
+      char *new_name = new char [strlen (file_name) + length + 1];
+      strcpy (new_name, strdup (CHROOT_INPUT_DIR));
+      return strcat (new_name, file_name);
+    }
+  else
+    return strdup (file_name);
+}
+
 void
 print_cgi_header()
 {
